<?php

namespace Emixion\Calendar\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Emixion\Calendar\Models\Calendars;

class CalendarsPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the calendars.
     *
     * @param User $user
     * @param Calendars $calendars
     *
     * @return bool
     */
    public function view(User $user, Calendars $calendars)
    {
        if ($user->canDo('calendar.calendars.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $calendars->user_id;
    }

    /**
     * Determine if the given user can create a calendars.
     *
     * @param User $user
     * @param Calendars $calendars
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('calendar.calendars.create');
    }

    /**
     * Determine if the given user can update the given calendars.
     *
     * @param User $user
     * @param Calendars $calendars
     *
     * @return bool
     */
    public function update(User $user, Calendars $calendars)
    {
        if ($user->canDo('calendar.calendars.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $calendars->user_id;
    }

    /**
     * Determine if the given user can delete the given calendars.
     *
     * @param User $user
     * @param Calendars $calendars
     *
     * @return bool
     */
    public function delete(User $user, Calendars $calendars)
    {
        if ($user->canDo('calendar.calendars.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $calendars->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
