<?php

namespace Emixion\Calendar\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Emixion\Calendar\Models\Events;

class EventsPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the events.
     *
     * @param User $user
     * @param Events $events
     *
     * @return bool
     */
    public function view(User $user, Events $events)
    {
        if ($user->canDo('calendar.events.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $events->user_id;
    }

    /**
     * Determine if the given user can create a events.
     *
     * @param User $user
     * @param Events $events
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('calendar.events.create');
    }

    /**
     * Determine if the given user can update the given events.
     *
     * @param User $user
     * @param Events $events
     *
     * @return bool
     */
    public function update(User $user, Events $events)
    {
        if ($user->canDo('calendar.events.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $events->user_id;
    }

    /**
     * Determine if the given user can delete the given events.
     *
     * @param User $user
     * @param Events $events
     *
     * @return bool
     */
    public function delete(User $user, Events $events)
    {
        if ($user->canDo('calendar.events.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $events->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
