<?php

namespace Emixion\Calendar\Providers;

use Illuminate\Support\ServiceProvider;

class CalendarServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'calendar');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'calendar');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('calendar', function ($app) {
            return $this->app->make('Emixion\Calendar\Calendar');
        });

// Bind Calendars to repository
        $this->app->bind(
            \Emixion\Calendar\Interfaces\CalendarsRepositoryInterface::class,
            \Emixion\Calendar\Repositories\Eloquent\CalendarsRepository::class
        );
        // Bind Events to repository
        $this->app->bind(
            \Emixion\Calendar\Interfaces\EventsRepositoryInterface::class,
            \Emixion\Calendar\Repositories\Eloquent\EventsRepository::class
        );

        $this->app->register(\Emixion\Calendar\Providers\AuthServiceProvider::class);
        $this->app->register(\Emixion\Calendar\Providers\EventServiceProvider::class);
        $this->app->register(\Emixion\Calendar\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['calendar'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/calendar.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/calendar/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/calendar/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/calendar')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
